# Copyright (c) Microsoft. All rights reserved.

"""
Common models for MCP tooling.

This module defines data models used across the MCP tooling framework.
"""

from .mcp_server_config import MCPServerConfig

__all__ = ["MCPServerConfig"]
